@@ -4,7 +4,7 @@ Main interface for evidently service.
 Usage::
 
     ```python
-    import boto3
+    from boto3.session import Session
     from mypy_boto3_evidently import (
         Client,
         CloudWatchEvidentlyClient,
@@ -14,10 +14,8 @@ Usage::
         ListProjectsPaginator,
     )
 
-    session = boto3.Session()
-
-    client: CloudWatchEvidentlyClient = boto3.client("evidently")
-    session_client: CloudWatchEvidentlyClient = session.client("evidently")
+    session = Session()
+    client: CloudWatchEvidentlyClient = session.client("evidently")
 
     list_experiments_paginator: ListExperimentsPaginator = client.get_paginator("list_experiments")
     list_features_paginator: ListFeaturesPaginator = client.get_paginator("list_features")
